#!/usr/bin/python
# -*- coding: utf-8 -*-
# Source Creator - Qt GUI for creating source files from a template
# Copyright (C) 2009 A. S. Budden
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

# Core modules:
import os
import sys
import imp
import re
import optparse
import logging

from PyQt4 import QtGui, QtCore

from ConfigurationWindow import Ui_dlgConfiguration
from Settings import *


class Configuration(QtGui.QDialog):
	def __init__(self,
			settings,
			maindir=None,
			parent=None):

		QtGui.QDialog.__init__(self)

		self.settings = settings

		self.ui = Ui_dlgConfiguration()
		self.ui.setupUi(self)

		if maindir is None:
			maindir = GetMainDir()

		self.maindir = maindir

		self.ui.txtTemplateDir.setText(ReadGlobalConfig(
				'TemplatesDirectory',
				os.path.join(self.maindir, 'templates'),
				self.settings))
		self.ui.txtSourceDir.setText(ReadGlobalConfig('SourceDirectory',
				'Source',
				self.settings))
		self.ui.txtHeadersDir.setText(ReadGlobalConfig('HeadersDirectory',
				'Headers',
				self.settings))

		try:
			self.ui.buttonBox.accepted.connect(self.OnAccept)
			self.ui.btnTemplateBrowse.clicked.connect(self.OnTemplateBrowse)
		except AttributeError:
			QtCore.QObject.connect(self.ui.buttonBox, QtCore.SIGNAL("accepted()"),
					self.OnAccept)
			QtCore.QObject.connect(self.ui.btnTemplateBrowse, QtCore.SIGNAL('clicked()'),
					self.OnTemplateBrowse)

	def OnAccept(self):
		source_dir    = str(self.ui.txtSourceDir.text())
		headers_dir   = str(self.ui.txtHeadersDir.text())
		templates_dir = str(self.ui.txtTemplateDir.text())
		if not source_dir.isalpha():
			source_dir = "".join([i for i in source_dir if i.isalpha()])
		if not headers_dir.isalpha():
			headers_dir = "".join([i for i in headers_dir if i.isalpha()])
		if not os.path.isdir(templates_dir):
			templates_dir = ReadGlobalConfig('TemplatesDirectory',
					os.path.join(self.maindir, 'templates'),
					self.settings)
		WriteGlobalConfig('SourceDirectory', source_dir, self.settings)
		WriteGlobalConfig('HeadersDirectory', headers_dir, self.settings)
		WriteGlobalConfig('TemplatesDirectory', templates_dir, self.settings)


	def OnTemplateBrowse(self):
		Directory = QtGui.QFileDialog.getExistingDirectory(
				self, "Select destination directory",
				self.ui.txtTemplateDir.text(),
				QtGui.QFileDialog.ShowDirsOnly | QtGui.QFileDialog.DontResolveSymlinks)
		if Directory:
			self.ui.txtTemplateDir.setText(Directory)


if __name__ == "__main__":
	application = QtGui.QApplication(sys.argv)
	window = Configuration(None)
	window.show()
	application.exec_()

