#!/usr/bin/python
# -*- coding: utf-8 -*-
# Source Creator - Qt GUI for creating source files from a template
# Copyright (C) 2009 A. S. Budden
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

# Core modules:
import os
import sys
import imp
import re
import optparse
import logging

from PyQt4 import QtGui, QtCore


def MainIsFrozen():
	return (hasattr(sys, "frozen") or # new py2exe
			hasattr(sys, "importers") # old py2exe
			or imp.is_frozen("__main__")) # tools/freeze

def GetMainDir():
	if MainIsFrozen():
		return os.path.abspath(os.path.dirname(sys.executable))
	return os.path.abspath(os.path.dirname(sys.argv[0]))

def ReadGlobalOption(option, default, settings):
	result = settings.value('Configuration/' + option)
	if result.isNull():
		return default
	else:
		return result.toBool()

def ReadGlobalConfig(option, default, settings):
	result = settings.value('Configuration/' + option)
	if result.isNull():
		return default
	else:
		return str(result.toString())

def WriteGlobalConfig(option, value, settings):
	settings.setValue('Configuration/' + option, QtCore.QVariant(str(value)))

def WriteGlobalOption(option, value, settings):
	settings.setValue('Configuration/' + option, QtCore.QVariant(bool(value)))

def ReadConfig(config, settings):
	if not config['Remember']:
		return config['Default']

	result = settings.value('Defaults/' + config['Pattern']).toString()
	if result:
		return str(result)
	else:
		return config['Default']

def WriteConfig(config, value, settings):
	if not config['Remember']:
		return

	settings.setValue('Defaults/' + config['Pattern'], QtCore.QVariant(str(value)))

def WriteOption(config, value, settings):
	if not config['Remember']:
		return
	settings.setValue('Defaults/' + config['Pattern'], QtCore.QVariant(bool(value)))


def ReadOption(option, settings):
	if not option['Remember']:
		return option['Default']

	result = settings.value('Defaults/' + option['Name']).toBool()
	if result is not None:
		return result
	else:
		return config['Default']
